@@ -1,6 +1,6 @@
 ## Domain Registry Interface, Protocol superclass
 ##
-## Copyright (c) 2005-2011,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005-2011,2013-2014 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -61,7 +61,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2011,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005-2011,2013-2014 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -140,10 +140,13 @@ sub _load
  my $etype='protocol/'.$self->name();
  my $version=$self->version();
 
+ my %skip = map { substr($_,1) => 1 } grep { /^-/ } @classes;
+
  my (%c,%done,@done);
  foreach my $class (@classes)
  {
-  next if exists($done{$class});
+  next if exists $done{$class} || $class=~m/^-/ || exists $skip{$class};
+  $self->log_output('debug','core',sprintf('Loading class "%s"',$class));
   Net::DRI::Util::load_module($class,$etype);
   Net::DRI::Exception::method_not_implemented('register_commands',$class) unless $class->can('register_commands');
   my $rh=$class->register_commands($version);
