@@ -1,6 +1,6 @@
 ## Domain Registry Interface, .CAT EPP extensions
 ##
-## Copyright (c) 2006,2008,2009 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2008,2009,2012 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -47,7 +47,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008,2009 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2008,2009,2012 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -70,9 +70,7 @@ sub setup
           });
  $self->capabilities('host_update','name',undef);
  $self->capabilities('domain_update','name_variant',['add','del']);
- $self->capabilities('domain_update','lang',['set']);
- $self->capabilities('domain_update','maintainer',['set']);
- $self->capabilities('domain_update','intended_use',['set']);
+ foreach my $o (qw/lang maintainer intended_use registrant_disclosure/) { $self->capabilities('domain_update',$o,['set']); }
  foreach my $o (qw/status contact/) { $self->capabilities('defreg_update',$o,['add','del']); }
  foreach my $o (qw/registrant auth maintainer trademark/) { $self->capabilities('defreg_update',$o,['set']); }
  return;
